const { axiosPost, axiosGet, encrypt } = require('./public');

const queryGroupByPath = groupPath => {
    const path = '/api/v1/localUserGroup/queryGroupByPath'
    const query = {
        path: groupPath
    }
    return new Promise((resolve, reject) => {
        axiosGet(path, query).then(res => {
            if (res.status === 200) {
                resolve(res.data)
            } else {
                reject()
            }
        }).catch(err => {
            reject(err)
        })
    })
}

const createUser = async (name, password, groupId, status = null, inheritGroup = null, description = null, phone = null, email = null, authComposeId = '', expiredTime = null, pwdModel = 'rsa', userPolicyId) => {
    const path = '/api/v2/localUser/createUser'

    // 必填参数
    const data = {
        name,
        password,
        groupId,
        authComposeId,
        userPolicyId,
        pwdModel
    }

    // 非必填参数
    if (phone) {
        data.phone = phone
    }
    if (description) {
        data.description = description
    }
    if (email) {
        data.email = email
    }
    if (status) {
        data.status = status
    }
    if (inheritGroup) {
        data.inheritGroup = inheritGroup
    }
    if (expiredTime) {
        data.expiredTime = expiredTime
    }

    if (data.pwdModel === 'rsa') {
        data.password = await encrypt(password)
    }

    return new Promise((resolve, reject) => {
        axiosPost(path, data).then(res => {
            if (res.status === 200) {
                resolve(res)
            }
        }).catch(err => {
            reject(err)
        })
    })
}

async function example1_create_local_user() {
    const name = "zhangsan"
    const password = "user@1234"
    const phone = "13800000000"
    const groupPath = "/openapi/aTrust"

    const group = await queryGroupByPath(groupPath)
    if (!group.data.id) {
        console.log('查询不到当前用户目录，请检查GroupPath')
        return
    }

    const createUserRs = await createUser(name, password, group.data.id, null, null, null, phone)
    console.log(createUserRs.data)
}

example1_create_local_user();